@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::FormatAssertion;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Format-Assertion vocabulary
 
-our $VERSION = '0.515';
+our $VERSION = '0.516';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -137,19 +137,22 @@ sub keywords {
 
 sub _traverse_keyword_format {
   my ($self, $schema, $state) = @_;
-
   return if not assert_keyword_type($state, $schema, 'string');
+  return 1;
+}
 
-  if ($schema->{format} eq 'iri-reference' or $schema->{format} eq 'uri-template') {
-    return E($state, 'unimplemented format "%s"', $schema->{format});
-  }
+sub _eval_keyword_format {
+  my ($self, $data, $schema, $state) = @_;
+
+  return E($state, 'unimplemented format "%s"', $schema->{format})
+    if $schema->{format} eq 'iri-reference' or $schema->{format} eq 'uri-template';
 
   try {
     if ($schema->{format} eq 'date-time' or $schema->{format} eq 'date') {
       +require Time::Moment;
     }
     elsif ($schema->{format} eq 'email' or $schema->{format} eq 'idn-email') {
-      +require Email::Address::XS; Email::Address::XS->VERSION(1.01);
+      +require Email::Address::XS; Email::Address::XS->VERSION(1.04);
     }
     elsif ($schema->{format} eq 'hostname' or $schema->{format} eq 'idn-hostname') {
       +require Data::Validate::Domain;
@@ -161,11 +164,6 @@ sub _traverse_keyword_format {
   catch ($e) {
     return E($state, 'cannot validate format "%s": %s', $schema->{format}, $e);
   }
-  return 1;
-}
-
-sub _eval_keyword_format {
-  my ($self, $data, $schema, $state) = @_;
 
   # first check the subrefs from JSON::Schema::Modern->new(format_evaluations => { ... })
   # and add in the type if needed
@@ -197,7 +195,7 @@ JSON::Schema::Modern::Vocabulary::FormatAssertion - Implementation of the JSON S
 
 =head1 VERSION
 
-version 0.515
+version 0.516
 
 =head1 DESCRIPTION
 
